@@ -16,7 +16,7 @@ OP::Int - Overloaded object class for integers
 
 =head1 DESCRIPTION
 
-Extends L<OP::Num> and L<Data::Integer>.
+Extends L<OP::Num>
 
 =head1 SYNOPSIS
 
@@ -37,7 +37,7 @@ use warnings;
 
 use OP::Enum::Bool;
 
-use base qw| OP::Num Data::Integer |;
+use base qw| OP::Num |;
 
 use overload fallback => true, %OP::Num::overload;
 
